const gapic = Object.freeze({
    v2: require('dialgflow-norbit/src/v2'),
    v2beta1: require('dialgflow-norbit/src/v2beta1'),
  });
  
  /**
   * The `dialogflow` package has the following named exports:
   *
   * - `SessionsClient` - Reference to
   *   {@link v2.SessionsClient}
   * - `v2` - This is used for selecting or pinning a
   *   particular backend service version. It exports:\
   *     - `SessionsClient` - Reference to
   *       {@link v2.SessionsClient}
   *
   * @module {object} dialogflow
   * @alias nodejs-dialogflow
   *
   * @example <caption>Install the client library with <a href="https://www.npmjs.com/">npm</a>:</caption>
   * npm install --save dialogflow
   *
   * @example <caption>Import the client library:</caption>
   * const dialogflow = require('dialogflow');
   *
   * @example <caption>Create a client that uses <a href="https://goo.gl/64dyYX">Application Default Credentials (ADC)</a>:</caption>
   * const client = new dialogflow.AgentsClient();
   *
   * @example <caption>Create a client with <a href="https://goo.gl/RXp6VL">explicit credentials</a>:</caption>
   * const client = new dialogflow.AgentsClient({
   *   projectId: 'your-project-id',
   *   keyFilename: '/path/to/keyfile.json',
   * });
   */
  
  /**
   * @type {object}
   * @property {constructor} SessionsClient
   *   Reference to {@link v2.SessionsClient}
   */
  module.exports = gapic.v2;
  
  /**
   * @type {object}
   * @property {constructor} SessionsClient
   *   Reference to {@link v2.SessionsClient}
   */
  module.exports.v2 = gapic.v2;
